import React from 'react'
import { Button, TextField } from '@pubsweet/ui'
import { omit } from 'lodash'
import { withTheme } from 'styled-components'
import { Portal, Buttons, Close, CloseButton } from '../ui'
import { ManuscriptMutations } from '../SubmissionMutations'
import GrantSearch from '../GrantSearch'

const MetaEdit = withTheme(({ theme, close, manuscript, toEdit, ...props }) => {
  const { meta } = manuscript
  const { fundingGroup: grants, releaseDelay } = meta
  const fundingGroup = grants
    ? grants.map(g => {
        const n = omit(g, '__typename')
        n.pi = omit(g.pi, '__typename')
        return n
      })
    : []
  return (
    <Portal style={{ backgroundColor: theme.colorBackground }} transparent>
      <Close>
        <CloseButton onClick={close} />
      </Close>
      <React.Fragment>
        {(() => {
          switch (toEdit) {
            case 'grants':
              return (
                <GrantSearch
                  changedGrants={props.updateGrants}
                  hideEmbargo
                  selectedGrants={fundingGroup}
                />
              )
            case 'embargo':
              return (
                <TextField
                  label="Enter embargo in months"
                  name="embargo"
                  onChange={e => props.updateEmbargo(e.target.value)}
                  value={releaseDelay}
                />
              )
            default:
              return null
          }
        })()}
      </React.Fragment>
      <Buttons right>
        <Button onClick={close}>Cancel</Button>
      </Buttons>
    </Portal>
  )
})

export default ManuscriptMutations(MetaEdit)
