const lodash = require('lodash')
const rfr = require('rfr')
const FileAccess = require('./data-access')

// const dataAccess = new FileAccess()

const { minioClient } = rfr('server/modules/pubsweet-component-minio')

const empty = {
  filename: '',
  label: '',
  type: 0,
  mime_type: '',
  size: 0,
  url: '',
}

const FileManager = {
  find: FileAccess.selectById,
  findByManuscriptId: FileAccess.selectByManuscriptId,
  delete: FileAccess.delete,
  deleteById: FileAccess.deleteById,
  deleteByManIdAndType: FileAccess.deleteByManIdAndType,
  new: (props = {}) => lodash.merge({}, empty, props),
  save: async (file, userId) => {
    let id = { file }
    if (file.id) {
      const updated = await FileAccess.update(file, userId)
      if (!updated) {
        throw new Error('File not found')
      }
    } else {
      id = await FileAccess.insert(file, userId)
    }

    return { ...file, id }
  },
  putContent: async (file, content, { size } = {}) => {
    if (!file.id) {
      throw new Error('File has no ID, must be saved first')
    }

    const data = process.env.MINIO_DATA_FOLDER_NAME
    const metaData = {
      'Content-Type': file.mimetype,
      'Content-Length': size,
    }
    return minioClient.putObject(
      process.env.MINIO_BUCKET,
      `${data}/${file.url}/${file.id}`,
      content,
      metaData,
    )
  },
  getContent: async file => {
    const data = process.env.MINIO_DATA_FOLDER_NAME
    const Body = await minioClient.getObject(
      process.env.MINIO_BUCKET,
      `${data}/${file.url}/${file.id}`,
    )
    return Body
  },
  modelName: 'File',

  model: FileAccess,
}

module.exports = FileManager
