const config = require('config')
const rfr = require('rfr')
const authentication = require('../user/authentication')

const { sendMail, userMessage } = rfr('server/email')
const { resetPasswordTemplate } = rfr('server/email/templates')
const { UserManager, NoteManager } = rfr('server/xpub-model')

const { url } = config['epmc-email']

const resolvers = {
  Mutation: {
    async epmc_email(
      _,
      { manuscriptId, to, subject, messageInHtml },
      { user },
    ) {
      if (!user) {
        throw new Error('You are not authenticated!')
      }
      const uniqueTo = [...new Set(to)]
      await Promise.all(
        uniqueTo.map(async userId => {
          const email =
            userId === 'helpdesk'
              ? 'helpdesk@europepmc.org'
              : await UserManager.findEmail(userId)
          await userMessage(email, subject, messageInHtml)
          // Create a note
          const content = {
            to: userId,
            subject,
            message: messageInHtml,
          }
          const note = {
            manuscriptId,
            notesType: 'userMessage',
            content: JSON.stringify(content),
          }
          await NoteManager.create(note, user)
        }),
      )

      return true
    },
    /* async epmc_addReviewer(_, data, { user }) {
      await reviewerEmail(data)
      return true
    }, */
    async epmc_emailPasswordResetLink(_, { email }, ctx) {
      const user = await UserManager.findByEmail(email)
      if (!user) {
        throw new Error('Email not registered')
      }
      const token = authentication.token.create({
        email,
        id: user.id,
      })
      const passwordResetLink = `${url}password-reset/${token}`

      await sendMail(
        email,
        'Europe PMC Plus - Reset Password',
        resetPasswordTemplate(user, passwordResetLink),
      )
      return true
    },
  },
}

module.exports = resolvers
